@@ -7,14 +7,15 @@ if(Nrs <= 0 || shape <= 0)
 stop("Nrs and shape must be positive.")
 
 for(n in Nrs){
-if(all(n!=n[1])){
+if(any(n != n[1])){
 warning("Unequal number of reads across samples.")
 break
 }
 }
 
-Nrs <- t(t(Nrs))
-Sample.counts <- t(apply(Nrs, 1, function(x){rmultinom(n=1, size=x, prob=rdirichlet(1, shape))}))
+Sample.counts <- matrix(0, length(Nrs), length(shape))
+for(i in 1:length(Nrs))
+Sample.counts[i,] <- rmultinom(n=1, size=Nrs[i], prob=dirmult::rdirichlet(1, shape))
 
 return(Sample.counts)
 }
