@@ -1,7 +1,7 @@
 Xdc.statistics <-
 function(group.data, epsilon=10^(-4)){
 fit <- lapply(group.data, function(x, epsilon){
-dirmult(x, init=DM.MoM(x)$gamma, epsilon, trace=FALSE)
+dirmult::dirmult(x, initscalar=DM.MoM(x)$theta, epsilon=epsilon, trace=FALSE)
 }, epsilon=epsilon)
 
 logliks <- unlist(lapply(fit, function(x){x$loglik}))
@@ -9,8 +9,8 @@ groupData <- NULL
 
 for(i in 1:length(group.data))
 groupData <- rbind(groupData, group.data[[i]])
+fit.group <- dirmult::dirmult(groupData, initscalar=DM.MoM(groupData)$theta, epsilon=epsilon, trace=FALSE)
 
-fit.group <- dirmult(groupData, init=DM.MoM(groupData)$gamma, epsilon=epsilon, trace=FALSE)
 Xdc <- -2*(fit.group$loglik-sum(logliks))
 
 return(Xdc)
